package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````,`*``!````]1<``#0```"\L0````0`!30`(``)
M`"@`'``;``$``'#,H0``S*$``,RA```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!0````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#8H0``V*$```4```````$`
M`0```)"M``"0K0$`D*T!`,P"``#D$@``!@```````0`"````G*T``)RM`0"<
MK0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DD*T`
M`)"M`0"0K0$`<`(``'`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50`;HPDR0)U]5;.,9)WUOYH>:ET'1Q$```!1````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(TXH!)%B@0("%$```!2````5@``
M`%L```!<````8P```&0```!E````9P```&@`````````:@```&L```!L````
M;@```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_Y`ZX
MC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>O
MS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)````
M``````````````````````#\$@````````,`"P``````F*T!```````#`!0`
MN`(`````````````$@```&8#`````````````!(````Z`P`````````````B
M````?P,`````````````$0```"D$`````````````!(````1````````````
M```@````*0(`````````````$@````P#`````````````!(```!7`P``````
M```````2````)0$`````````````$@```)T#`````````````!$```#(````
M```````````2````TP(`````````````$@```)<!`````````````!(```"_
M`@`````````````2````F```````````````$@```"`!`````````````!(`
M``#:`@`````````````2````:0(`````````````$@```#@"````````````
M`!(```!Z`@`````````````2````AP(`````````````$@```!4!````````
M`````!$```![`0`````````````2````]P``````````````$0```$D!````
M`````````!(````3`P`````````````2````!0,`````````````$0```!P#
M`````````````!(```#6```````````````2````Q0$`````````````$@``
M`"$"`````````````!(```"R`0`````````````2````\P(`````````````
M$@````D"`````````````!(```"^`0`````````````2````;0,`````````
M````$@```%<!`````````````!(````M```````````````@````G`(`````
M````````$@```$H"`````````````!(```"J`@`````````````2````T`$`
M````````````$0```'@``````````````!(````I`P`````````````2````
MIP``````````````$@```!`"`````````````!(```!)`P`````````````2
M````LP``````````````$@```%<"`````````````!(```!P`0``````````
M```2````@0(`````````````$@```+$"`````````````!(````V`0``````
M```````2````:@``````````````$@```"H!`````````````!(```"G`0``
M```````````2````Q0(`````````````$@````0!`````````````!(```"5
M`@`````````````2````7P,`````````````$@```*,"`````````````!(`
M``")`0`````````````2````AP``````````````$@```(`#````````````
M`"$````\```````````````@````,`,`````````````$@```.@`````````
M`````!(```!G`0`````````````2````4```````````````(````($#````
M`````````!$```#[`@`````````````2````3P(`````````````$@```(\"
M`````````````!(````#`@`````````````2````Z`(`````````````$@``
M`&`"`````````````!(```#O`0`````````````2````W@,``'3``0``````
M$``8`#($``#E7P``3````!(`#0``!```D&`````````2``X`5P0``$55``#D
M!P``$@`-`'H#```I%@``S`$``!(`#0`&!```"5````0````2``T`SP,``%RP
M`0``````$``8`+@$```-4```D`$``!(`#0"R!```_!(````````2``L`Y00`
M`"E=``"\`@``$@`-`,,#``!<L`$``````!``&``^!```G5$``!8````2``T`
M9`0``)A@```$````$0`/`/$#``!TP`$``````!``&`#I`P``=,`!```````0
M`!@`L`0``.E.```X````$@`-`,4$``!M5```V````!(`#0#7!```_5,``&``
M```2``T`KP,```"P`0``````$``7`$L$``"U40``K````!(`#0"\`P``7+`!
M```````0`!<`F00``%BP`0`$````$0`7`/8#``"-8````@```!(`#0")!```
M46```#P````2``T`M0,``/47````````$@`-`+$#````L`$``````"``%P`7
M!```750``!`````2``T`W0,``'3``0``````$``8`',$``!M3P``G````!(`
M#0"C!```85(``)P!```2``T``&QI8G!E<FPN<V\N-2XR,@!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R
M0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A
M<`!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O
M<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV
M`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S
M961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B
M;W)T`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L
M>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L
M:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L
M:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB
M8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L9"UL:6YU>"UA<FUH9BYS;RXS`%]?
M<W1A8VM?8VAK7V=U87)D`%]?9&%T85]S=&%R=`!?961A=&$`7U]B<W-?<W1A
M<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L
M:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N
M86UE`'!A<E]M:W1M<&1I<@!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E
M;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT````
M```````"``(``@`"``(````#``(``@`"``0````"`````@```````@`"``(`
M`@`"`````````````@`"``(```````,````"``,``@`"```````"``(``@``
M`````@````,``@````(````"``(````````````"`````@`"``(```````(`
M```"``````````(``@`"``(``P`"``(``P`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
MB0,``!`````@````%&EI#0``!`#[!`````````$``0#?`0``$````"`````4
M:6D-```#`/L$`````````0`!`"X"```0`````````!1I:0T```(`^P0`````
M``"0K0$`%P```)2M`0`7````N*\!`!<```#<KP$`%P```.2O`0`7````[*\!
M`!<````$L`$`%P````RP`0`7````$+`!`!<````4L`$`%P```!BP`0`7````
M'+`!`!<````@L`$`%P```"BP`0`7````++`!`!<````TL`$`%P```#BP`0`7
M````/+`!`!<```!`L`$`%P```$2P`0`7````3+`!`!<```!0L`$`%P```%BP
M`0`7````O*\!`!4%``#`KP$`%0@``,2O`0`5#0``R*\!`!40``#,KP$`%1D`
M`-"O`0`5&P``U*\!`!4>``#8KP$`%2D``."O`0`5+0``Z*\!`!4X``#PKP$`
M%4(``/2O`0`51```^*\!`!5(``#\KP$`%4D``+BN`0`6`P``O*X!`!8$``#`
MK@$`%@4``,2N`0`6!P``R*X!`!8)``#,K@$`%@H``-"N`0`6"P``U*X!`!8,
M``#8K@$`%@X``-RN`0`6#P``X*X!`!81``#DK@$`%A(``.BN`0`6$P``[*X!
M`!84``#PK@$`%A4``/2N`0`6%@``^*X!`!87``#\K@$`%A@```"O`0`6&@``
M!*\!`!8<```(KP$`%AT```RO`0`6'P``$*\!`!8@```4KP$`%B$``!BO`0`6
M(@``'*\!`!8C```@KP$`%B0``"2O`0`6)0``**\!`!8F```LKP$`%B<``#"O
M`0`6*```-*\!`!8I```XKP$`%BH``#RO`0`6*P``0*\!`!8L``!$KP$`%BX`
M`$BO`0`6+P``3*\!`!8P``!0KP$`%C$``%2O`0`6,@``6*\!`!8S``!<KP$`
M%C0``&"O`0`6-0``9*\!`!8V``!HKP$`%C<``&RO`0`6.0``<*\!`!8Z``!T
MKP$`%CL``'BO`0`6/```?*\!`!8]``"`KP$`%CX``(2O`0`6/P``B*\!`!9`
M``",KP$`%D$``)"O`0`610``E*\!`!9&``"8KP$`%D<``)RO`0`62@``H*\!
M`!9+``"DKP$`%DP``*BO`0`630``K*\!`!9.``"PKP$`%D\``+2O`0`64```
M"$`MZ4T!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y92;`0``QH_B&<J,XI3[O.4`
MQH_B&<J,XHS[O.4`QH_B&<J,XH3[O.4`QH_B&<J,XGS[O.4`QH_B&<J,XG3[
MO.4`QH_B&<J,XFS[O.4`QH_B&<J,XF3[O.4`QH_B&<J,XES[O.4`QH_B&<J,
MXE3[O.4`QH_B&<J,XDS[O.4`QH_B&<J,XD3[O.4`QH_B&<J,XCS[O.4`QH_B
M&<J,XC3[O.4`QH_B&<J,XBS[O.4`QH_B&<J,XB3[O.5X1\!&`,:/XAG*C.(8
M^[SE`,:/XAG*C.(0^[SE`,:/XAG*C.((^[SE`,:/XAG*C.(`^[SE`,:/XAG*
MC.+X^KSE`,:/XAG*C.+P^KSE`,:/XAG*C.+H^KSE`,:/XAG*C.+@^KSE`,:/
MXAG*C.+8^KSE`,:/XAG*C.+0^KSE`,:/XAG*C.+(^KSE`,:/XAG*C.+`^KSE
M`,:/XAG*C.*X^KSE`,:/XAG*C.*P^KSE`,:/XAG*C.*H^KSE`,:/XAG*C.*@
M^KSE`,:/XAG*C.*8^KSE`,:/XAG*C.*0^KSE`,:/XAG*C.*(^KSE`,:/XAG*
MC.*`^KSE`,:/XAG*C.)X^KSE`,:/XAG*C.)P^KSE`,:/XAG*C.)H^KSE`,:/
MXAG*C.)@^KSE`,:/XAG*C.)8^KSE`,:/XAG*C.)0^KSE>$?`1@#&C^(9RHSB
M1/J\Y7A'P$8`QH_B&<J,XCCZO.4`QH_B&<J,XC#ZO.4`QH_B&<J,XBCZO.4`
MQH_B&<J,XB#ZO.4`QH_B&<J,XACZO.4`QH_B&<J,XA#ZO.4`QH_B&<J,X@CZ
MO.4`QH_B&<J,X@#ZO.4`QH_B&<J,XOCYO.4`QH_B&<J,XO#YO.4`QH_B&<J,
MXNCYO.4`QH_B&<J,XN#YO.4`QH_B&<J,XMCYO.4`QH_B&<J,XM#YO.4`QH_B
M&<J,XLCYO.4`QH_B&<J,XL#YO.4`QH_B&<J,XKCYO.4`QH_B&<J,XK#YO.4`
MQH_B&<J,XJCYO.4`QH_B&<J,XJ#YO.4`QH_B&<J,XICYO.4`QH_B&<J,XI#Y
MO.7PM8FP7DQ?2WQ$!9`$D06H`Y($J>98`ZHS:`>3__<^[UE*6DNB6.!8$48$
M\.W\6$OC6!]X`"]QT%9+Y5@H:/_WVN^0^!XT`D8H:$/P`@."^!XT__?0[P6;
M!3.S\8!/D/@>)$+P`0*`^!XD=-*8`/_WVNY)2P2=3_`$#GM$1TI(22]H>D0<
M:'E$1DM[1$/X].Q"8`6:P6`!*D/X\`P'8,B_*QV$8,2_!>N"!0#Q#`$%W5/X
M!$NK0D'X!$_YT3I/`O&`00`D`S%_1`"40/@A0`-&5_CH7`,R-4DH1GE$__<J
M[P1&8+,R30:O?415^.@,__=P[C!(.49X1`/PPODHLRY+>T13^.@,__<^[O_W
M".\'FC-H($::0B[1";#PO?_W=NXF2GI$0OCH##BS__<F[AE+Y5@H:/_W7N^`
M^(UV?N=7^.@,__<N[P1&S.=5^.P,0+$$\#3\T^<:2QI(X5AX1/_WO.X92#E&
M>$0#\(KY1?CL#``HQ-#LY__W$NX!(/_W@NYXF`$`&`$``#P!``!$`0``)`$`
M`"`!``"RF0$`*DT``"I-``"BJ@$`9JH!`!LX``!$J@$`;DH``"RJ`0`*J@$`
M-`$``#1+``":20``3_``"T_P``X"O&I&!+0!M-_X)*`(HYI$W_@@P%KX#,!-
M^`3-!DM:^`,P!DA:^```__<J[O_WX.Z`E@$`#`$``#@!``!``0``%#"?Y10@
MG^4#,(_@`B"3YP``4N,>_R\!#O__ZF"6`0`L`0``!TL(2'M$"$IX1`,S&QIZ
M1`8K`]D%2]-8`[$81W!'`+_TEP$`\)<!`#J6`0`4`0``"$D)2'E$"4MX1`D:
M>T2)$`'KT7%)$`/0!4J;6`.Q&$=P1P"_Q)<!`,"7`0`,E@$`3`$```BU"DL*
M2GM$>D0;>&NY"4O36".Q"$M[1!AH__<J[?_WO?\&2P$B>T0:<`B]CI<!`-R5
M`0`0`0``)I<!`&Z7`0`'2`BU>$0":`9+>T02N;WH"$"[YP1*FU@`*_C0F$?V
MYXR4`0":E0$`2`$``-_XQ"[?^,0^+>GP3WI$K?5!?0#Q,`8>K`#Q<`<`E``E
M')"V1M-8O$8=DQMHOY->^`@_$#0#E1NZ1/@0/-[X!!#F143X#%Q/Z@$J3^H1
M(T_J$6L"DT_J`6$*]'\"0NH!`MWI`@%>1D_P``-"Z@8"0^H%`P#T?T!/\``!
M0NH``D/J`0-$Z0(CTM$-\7`.#?4<?'1&_ND"`=3I'&?4Z1(CU.D&17)`>T!B
M0&M`0D!+0)`8YD5/ZM)X2.I#"$_P``-`Z@@"SND@(^/1')\`):M&U^D(`=?I
M`#3-Z1(!`)FA1DY&`"2B1G4!T>D``9A&S>D"JT7JV&77Z0*KS>D$`2I&U^D$
M`=?I!F?<1LWI!HG31MWI$IK-Z0IG1T9\`=WI!&<B0P_VE%75Z0!%%NL)!LWI
M"`%'ZPH'L$84ZP@$ND;=Z0IGH$9<1H#J!@!%ZPH%"^H`"WE`H`BI1EY&HT;=
MZ0HT948,Z@$,&.L""(/J!@-)\0`)9T:L1JT'`Y4>1@.;&.L&`H3J!P1#ZIL#
M`Y-)ZP0#DD851D#JC'`>1EM&FP<"D]WI`B-/\``)S>D6O$_P``L"0UM&60$`
MG)!&W>D((\WI#E9!ZMIA@NH(`H/J"0/4Z0)%S>D,B9!&F4;=Z0HCS>D$JQ(9
M:T'=Z09%!.H(!`7J"06@1E1&8`%<1@_VO$S<Z0"\YPX;ZP(+3.L##,WI$+S=
MZ0@T0.H!"T'J!PS-Z0*\@^H(`]WI!HG=Z1"\;$`"F1OK`PM`1DSK!`P`G80(
M&^L!`$SQ``%&1H-&1.J)=(Q&6$;-Z1"\`"'5Z02\L@?-Z0(!(D,#G*Y&`IO8
M1MWI#JL`)6<!%$9'ZM-G"NH""MWI"",+Z@4+S>D.151&$NL(`EU&0^L,`P_V
M($O;Z0"K3_``#)E&`IL:ZP(*2^L)"]WI!(E>`0.;V0[=Z0PC(NH(""/J"0E"
M1DM&1^H&"$'J!PG-Z12)0NH$!MWI!(E#Z@4'&NL&"DOK!PO>Z09G249/\``)
MBP<4F4/JF`,:ZP$*049/ZH%R2_$`"QI#S>D4JT_P``O-Z02KDT8/]J`ST^D`
M(]WI!$62&0.9>T'=Z1!GS>D0O.`.!NH+!@?J#`=`ZD40W>D"1;)&NT;=Z0QG
MMAA?0=WI#B,BZ@0$(^H%!8L'2^H%"R)&!)P"F4KJ`@H6ZPH&3^I)%4_J1!A'
MZPL'0^J1`P*90.H(!``@%NL$"T_J@7)'\0`,&D/81M[I"&=%ZMAES>D8O)-&
M#_80,]/I`"-/\``,S>D,O$_J2!22&=WI%*M[0=WI#&=/ZMEA3_``#`KJ!@H+
MZ@<+S>D"J]WI#JL:ZP(*2^L#"]WI$"-61E]&W>D$JR+J"@HCZ@L+4D9;1MWI
M`JM*Z@(*2^H#"Q;K"@9%Z@0*1^L+!T'J!0O-Z0*KW>D$JU%&C`@"F1;K`0I/
M\``!1_$`"]WI!&?-Z1JK3_``"\WI`JM$ZH=TL@<B0]WI`D7-Z00!`"'>Z0IG
MDT9K`063#_98(]/I`"/@#LWI%+R2&7M!W>D89P?J#`<&Z@L&NT8%G[)&+D9'
MZM1D0.I&$-WI$&<%E+88`IQ?0=WI#"-D`2/J"0,$E"+J"`)+Z@,+W>D$14_J
MB7-*Z@(*0^J8`T_JB'(6ZPH&1.H`!$+J`P)'ZPL'%NL$"T_P``E'\0`,$$;-
MZ1"\V$;>Z0QG3^I)%0_VR!/3Z0`C1>K89<WI#@%/ZD@4DAG=Z1JK>T'=Z0YG
M3^K980`@"NH&"@OJ!PO-Z02K3_``#-WI#*L:ZP(*2^L#"]WI%"-61E]&W>D"
MJR+J"@HCZ@L+4D9;1MWI!*M*Z@(*2^H#"Q;K"@9%Z@0*1^L+!T'J!0O-Z02K
MW>D"JU%&C`@$F1;K`0I/\``!1_$`"]WI`F?-Z1BK3_``"\WI`JM$ZH=TL@<B
M0]WI`D7-Z00!WND.9Y-&:P$%DP_V$!/3Z0`CX`Z2&7M!W>D09\WI$+P'Z@P'
M!NH+!KM&!9^R1BY&1^K49$#J1A#=Z11G!90"G+887T'=Z0XC9`$$E"+J"`(C
MZ@D#W>D$14KJ`@I+Z@,+3^J)<Q;K"@9$Z@`$0^J8`T_JB')'ZPL'&D,6ZP0+
M3_``"4?Q``S>Z1!GV$;-Z12\DT8/]H@#T^D`(T_P``S-Z0R\DAG=Z1BK>T'=
MZ0QG3^I)%4_J2!0*Z@8*"^H'"\WI!*M%ZMAEW>D.JT_JV6$`($_P``P:ZP(*
M2^L#"]WI$"-61E]&W>D"JR+J"@HCZ@L+4D9;1MWI!*M*Z@(*2^H#"Q;K"@9%
MZ@0*1^L+!T'J!0O-Z02KW>D"JU%&C`@$F1;K`0I/\``!1_$`"]WI`F?-Z1BK
M3_``"\WI`JM$ZH=TL@<B0]WI`D7-Z00!WND29Y-&:P$%DP_RQ'/3Z0`CX`Z2
M&7M!W>D49\WI%+P'Z@P'!NH+!KM&!9^R1BY&1^K49$#J1A#=Z1!G!90"G+88
M7T'=Z0PC9`$$E-WI!$4BZ@@"(^H)`TKJ`@I+Z@,+3^J)<Q;K"@9$Z@`$0^J8
M`T_JB')'ZPL'&D,6ZP0+3_``"4?Q``S>Z11GV$;-Z1"\DT8/\CQST^D`(T_P
M``S-Z0Z\DAG=Z1BK>T'=Z0YG3^I)%4_J2!0*Z@8*"^H'"\WI!*M%ZMAEW>D,
MJT_JV6$`($_P``P:ZP(*2^L#"]WI%"-61E]&W>D"JR+J"@HCZ@L+4D9;1MWI
M!*M*Z@(*2^H#"Q;K"@9%Z@0*1^L+!T'J!0O-Z02KW>D"JU%&C`@$F1;K`0I/
M\``!1_$`"]WI`F?-Z1BK3_``"\WI`JM$ZH=TL@<B0]WI`D7-Z00!`"'>Z19G
MDT9K`063#_)X8]/I`"/@#I(9>T'=Z1!GS>D0O`?J#`<&Z@L&NT8%G[)&+D9'
MZM1D0.I&$-WI%&<%E+88`IQ?0=WI#B-D`2/J"0,$E"+J"`+=Z01%2^H#"T_J
MB7-*Z@(*0^J8`T_JB'(6ZPH&1.H`!$+J`P)'ZPL'%NL$"T_P``E'\0`,$$;>
MZ1AGV$8/\O13T^D`(T_J217-Z0P!1>K899(9S>D4O'M!W>D8J]WI#&=/ZD@4
M3^K980`@"NH&"@OJ!PO-Z02K3_``#-WI#JL:ZP(*2^L#"]WI$"-61E]&W>D"
MJR+J"@HCZ@L+4D9;1MWI!*M*Z@(*2^H#"Q;K"@9%Z@0*1^L+!T'J!0O-Z02K
MW>D"JU%&C`@$F1;K`0I/\``!1_$`"]WI`F?-Z1BK3_``"\WI`JM$ZH=TL@<B
M0]WI`D7-Z00!WND:9Y-&:P$%DP_R,%/3Z0`CX`Z2&7M!W>D49\WI%+P'Z@P'
M!NH+!KM&!9^R1BY&1^K49$#J1A#=Z1!G!90"G+887T'=Z0PC9`$$E-WI!$4B
MZ@@"(^H)`TKJ`@I+Z@,+3^J)<Q;K"@9$Z@`$0^J8`T_JB')'ZPL'&D,6ZP0+
M3_``"4?Q``S>Z1QGV$;-Z02\DT8/\JA#T^D`(T_P``S-Z0Z\DAG=Z1BK>T'=
MZ0YG3^I)%4_J2!0*Z@8*"^H'"\WI$*M%ZMAEW>D,JT_JV6$`(!KK`@I+ZP,+
MW>D4(U9&7T;=Z0*K(NH*"B/J"PM21EM&W>D0JTKJ`@I+Z@,+%NL*!D7J!`I'
MZPL'0>H%"\WI#*L`)=WI`JM11HP(#)D6ZP$*3_```4?Q``O=Z0)GS>D0JT_P
M``O-Z0(!3^I+$T3JAW2R!R)#`Y/>Z1YG3^J9`11&^Z/3Z0`CS>D,19(9>T'=
MZ01G)D`O0#1&`YX]1D;JVF8#EC!&W>D49[887T'=Z0XC(NH(`B/J"0/-Z00C
M3^I*$P*3W>D$(R)#*T/=Z0)%MAA?00`C!$,=1@`B3^J)<R!&0^J8`Q1&S>D$
M10613^J8!`24-!@$DT?Q``7=Z00!3^J(<D_P``F@1LWI`HE/\``)+D800R5&
M3$;=Z0*)`D831LWI%%8`(-[I(&=*1@`A4@'-Z00!!9)"1@_R-#G9Z0")T`X`
M(1CK!@A)ZP<)14;=Z1!X3D;-Z1`T'T`(Z@0(S>D8>-WI`HD%FT#J21!#ZMAC
MW>D.B063&.L%"$GK!@E&1D]&W>D,B0*<*.H*""GJ"PE"1DM&9`'=Z1B)!)3=
MZ01%2.H""$GJ`PD6ZP@&1.H`!$_JBW-'ZPD'0^J:`Q;K!`A/ZHIR1_$`"1I#
M3_``"T=&ND841LA&3^I+$\WI&'@`(-[I(F=/\``)S>D$`4U&!9-/ZMMAGJ/3
MZ0`CS>D.19(9!9Y[0=WI%'A&ZMIF!98(Z@D()T`P1D5&W>D,B3Q&&.L""$GK
M`PG=Z1`C1D9/1MWI`HDBZ@@((^H)"4)&2T;-Z0PCH$9/ZDH3!)/=Z0PT0^H(
M`RQ#F$86ZP@&W>D"B6=!W>D$101##4-!1LWI!$6,"`29`"46ZP$(3^J;`4?Q
M``G=Z0)GS>D,B4_P``G-Z0*)1.J'=+('(D/>Z21G%$;-Z01%W>D"1>`.<:34
MZ0`TFQE\0=WI&&?-Z1HTW>D$-!Y`)T#-Z11GW>D"1=WI$&?=Z1HC0.I%$$_J
M1!B2&=WI%$5[019&'T;=Z0XC(NH*`B/J"P,40QU#-AD`FV]!3^J+=4CJ``)%
MZIH%%NL""$7J`0O3Z28C1_$`"56AT>D``4_JBG1$Z@4*1T:`&,A&64'-Z1!X
M`D9/\``("T;=Z0P!P4961KA&,$!?1LWI%&<`)SE`S>D89T_J217=Z0YG1>K8
M9<WI#`%/ZD@4MAC=Z00!7T'=Z0(C(.H"`B'J`P/=Z0P!$$,90S881.H%`D]!
M%NL""T?Q``P`(UY&W>D"JV=&S>D.9Q]&`"!:1I4'4D:4!UI&1>J:!9$(1>H!
M#$3J!0O=Z11%`"$`FH3J"P2%Z@P%S>D"`7D!TNDH(R!&`Y$I1B6EU>D`1<WI
M#+S=Z1"KI!A=00.;BNH`"HOJ`0O-Z1"K<0'=Z02K0^K68P*1\@X0F1KK!`H#
MDTOK!0L:ZP$*W>D"`4+J1Q)+\0`+$$-/ZHEU&NL`"D7JF`5+\0`+3^J(=,WI
M`JM/ZID!`)M$Z@4(1>H!"=WI#$5`1D_P``O3Z2HC249$0,WI!`%-0`W@K_,`
M@)EY@EH`````H>O9;@````!LE0$`&`$```_VA&'1Z0`!3^I+&4_J2AB`&$GJ
MVFE90=WI#B-B0&M`W>D81<WI#B-)Z@@")!A-0;D(($8.G`091?$`!<WI#D6]
M![0'1>J6!0">W>D.B47J`0<8ZP((UNDL(T3J!08Y1DGQ``G=Z01%,$;-Z0X!
M#_888='I``%T0,WI$(E/\``)@!A/ZDD764'-Z10!W>D"$D?JV&=/ZMEC`I=A
M0`.33^I(%D_JBW4,1@R91>J:!8Y&W>D4`1#K#@!!\0`!`AE!\0`#S>D,(]WI
M`B-/ZHIT3^J;`43J!0HR0]WI#&=%Z@$+5$:V&$?Q``==1C)&W>D.JSM&S>D4
M(P":`",?1@_VB%S<Z0"\>0&*Z@0*TNDN(\WI#$541AOK`@M/ZHEU3.L##$'J
MUF/=Z1`21>J8!0.3\@YA0$+J1Q(,1@29&^L!`$SQ``$`&4_JB'2+1D_J1A$"
MD4OQ``&"1D3J!0B+1MWI`@%/ZID!1$9%Z@$)`)L00TU&W>D,B1KK``K3Z3`C
MB.H$",WI!$5+\0`+S>D0JT1&#_;X2=GI`(E/\``+O0<8ZP((3^I+$4GK`PE!
MZMICW>D4$D7JE@4#DT_JVF)A0$+J2Q(,1@Z9&.L!`$GQ``$`&4_JAG0`GHE&
M3^I*$0*12?$``8!&B4;=Z0(!N0@00T7J`0?6Z3(C1.H%!ACK``@Y1C!&S>D.
M`0_V@$'1Z0`!2?$`"=WI!$5/ZHMU@!C-Z12)64'-Z1@!W>D0$G1`3_``"4_J
M2!9A0$_J21='ZMAG3^K98PQ&#)D#DT7JF@4"EXY&W>D8`1#K#@!!\0`!`AE!
M\0`#S>D,(]WI`B-/ZHIT3^J;`43J!0HR0]WI#&=%Z@$+5$:V&$?Q``==1C)&
MW>D.JSM&S>D0(P":`",?1@_V[#S<Z0"\>0&*Z@0*TNDT(\WI#$541AOK`@M/
MZHEU3.L##$'JUF/=Z1021>J8!0.3\@YA0$+J1Q(,1@29`)L;ZP$`3/$``0`9
M3^J(=(M&3^I&$0*12_$``8)&1.H%"(M&W>D"`4_JF0%$1D7J`0D00QKK``K3
MZ38C34;=Z0R)S>D$14OQ``N(Z@0(S>D4JT_P``N]!T1&#_94.=GI`(E/ZDL1
M1>J6!1CK`@A)ZP,)0>K:8]WI$!)/ZMIB`Y-"ZDL284`,1@Z9&.L!`$GQ``$`
M&4_JAG0`GHE&3^I*$0*12?$``8!&B4;=Z0(!N0@00T7J`0?6Z3@C1.H%!ACK
M``@Y1C!&S>D.`0_VY"'1Z0`!2?$`"=WI!$5/ZHMU@!C-Z1")64'-Z1@!W>D4
M$G1`3_``"4_J2!9A0$_J21='ZMAG3^K98PQ&#)D"ET7JF@4#DXY&W>D8`1#K
M#@`-];Q^0?$``0(90?$``\WI#"/=Z0(C3^J*=$_JFP%$Z@4*,D/=Z0QG1>H!
M"U1&MAA'\0`'748R1MWI#JL[1LWI%",`F@`C'T8/]D@LW.D`O'D!S>D,1=+I
M.B.*Z@0*3^J)=1OK`@M41DSK`PQ!ZM9C`Y-%ZI@%W>D0$O(.`)M"ZD<284`,
M1@29&^L!`$SQ``$`&4_JB'2+1D_J1A$"D4OQ``&"1D3J!0B+1MWI`@%/ZID!
M1$9%Z@$)$$,:ZP`*T^D\(TU&W>D,B<WI!$5+\0`+B.H$",WI$*M/\``+O0=$
M1@_VL!G9Z0")3^I+$47JE@48ZP((2>L#"4'JVF/=Z1023^K:8@.30NI+$F%`
M#$8.F1CK`0!)\0`!`!E/ZH9T`)Z)1D_J2A$"D4GQ``&`1HE&W>D"`;D(UND^
M9Q!#1>H!`QCK``A$Z@4"2?$`"<WI%(E/\``)S>D"B1Q&$T8#FD_JFP7-Z0XT
M3^I"&=WI!!)90`_V(!/3Z0`CDAE[01]&`IM)ZM-IW>D0-$M`&$8,F]88`IM'
M\0`',AA/ZHIV3^I#&$?Q``-(Z@D`3^J+=Q(81^J:!T/Q``/>Z0")$48-]1A^
M&D;-Z1`2`"((1D?J!0,11D;J!P)/ZD$;'D;=Z0XT%4;-Z0Q6#_:L!]?I`&=3
M0$OJT&M/ZD`:%NL(!DOJ"@1'ZPD'W>D4B8CJ`P@$F_881_$`!Q;K"`)'\0`#
M$NL$"MWI`D5#\0`+4T;-Z12K3^J%>4GJE`D`),WI`#1@J]WI`D4!GM/I`"-/
MZH1XKPA(Z@D$2>H'!=WI#'A/ZD8;S>D"16=``)P/]BP)V>D`B4OJU&O=Z1!%
M&.L""(3J!P1)ZP,)CP@F1@Z<&.L$`@"<2?$``T_J@7EBJ4GJD`E/ZD0:E!E*
MZ@L"3_``"T/Q``5;1M'I`*M/ZH!XI!A(Z@D`2>H'`47Q``7-Z1"K(D;-Z0Y%
M!T;=Z0)%B$8/\KQVUND`5D_J0QO-Z01X1$#=Z1")2^K2:T_J0AH5ZP@%2^H*
M`$;K"0;=Z12)W>D`JXCJ!`@,G#=&+AE91D?Q``<6ZP@$1_$`!2081?$`!4_J
MBWG-Z1!%`"7-Z0!%9*Q)ZIH)3^J*>`&>CPC4Z0!%2.H)`$GJ!P'=Z01XS>D,
M`4_J1AL`F4=`#_(T>=GI`(D8ZP0(2^K1:TGK!0D"F41&349D&-WI#HE%\0`%
M`)E/ZH-YB.H'")\(9JM)ZI()3^I!&D9&H!E*Z@L$1?$``1#K!`I!\0`+3^J"
M>-/I`!)41LWI`JM/\``+749/ZDL;S>D4$DCJ"0%)Z@<"#_+`9]?I`&>(1DOJ
MVFN11MWI#!+-Z0Z)3^I*&H'J"`'=Z12)%NL(!D?K"0?=Z1")B.H!"`29=AA'
M\0`'%NL(`$KJ"P9'\0`!$.L&"]WI`&=!\0`,S>D4O$_P``Q/ZH=Y9T9)ZI8)
M7D;=Z0"K649/ZHIXBPAHJ4_J3!M/ZD8:T>D``4OJUFO-Z0`!2>H#`=WI#B-(
MZ@D`#_(L:=GI`(G-Z00!0D!+0-WI``$0ZP@`0>L)`=WI`HF)Z@,)#)N(Z@((
MS>D`B<`8`)M!\0`!3^J%><(82>J4"4'Q``/-Z0`CJPA*Z@L`2>H#`=WI`*M/
MZH1X:JP:ZP`*2.H)`(E&W>D$$M3I`$6`1H'J``%+\0`+S>D8JT_P``L*1@_R
MJ%'1Z0`!S>D"JP`9`YMI0<WI$(G=Z12)3^J'>0U&`IE/ZD,;B.H""$GJE@E+
MZM%K#IE$&`*91?$`!13K"`!/ZH9X;*Y/ZD$:1?$``4OJ"@*]"!#K`@M(Z@D`
M0?$`#%E&UND`JV)&S>D.$@`BS>D`$@&;2>H%`=WI$(D$1@U&S>D,18CJ``B)
MZ@$)7P$`FT!&248/\A19V>D`B4?JTV<`FQCK"@A)ZPL)W>D8JT1&7@&+Z@$+
M!)F*Z@`*S>D4JQ3K`0H4F4GQ``L`(QKK`0K=Z0(!3_``!,WI!#1'Z@8(2_$`
M"XL'!9,%FX0("D9$ZH%T0^J0`P63@P<$DY4(W>D$$AKK"`I/\``)0>H$`4+J
M!0)+\0`+S>D4JPA&;JD71@9&T>D`-$_J21O-Z01GT$80F4OJVFO-Z0(T3^I*
M&MWI#"/=Z0Y%$$8P0P1`($841C1`W>D"(R9&#_)81=7I`$42&6M!%$9`Z@8"
M8!A+Z@H&0_$``0&;@!A!\0`!S>D"`9T'`)O=Z0*K1>J3!0";&NL&"DOQ``O-
MZ1"KG`<!FT_P``O-Z0"K1.H%"@`DF0APJT7J`0O3Z0`!`"/-Z0(T`9S=Z01G
MS>D.JV0!`Y3=Z11%1NH*`P_RW#S<Z0"\'$`,FQOK``M/ZHAP(D8&Z@H$`YY,
MZP$,&^L#"P";0NH$"D_JB7$W1@">3^K39$_J0Q,"DT'JF`$!FT?JUF<#ETSQ
M``S=Z0)G&^L*"T3J0Q1/ZID#1NH$!D'J`P5`Z@$$3/$`#'*K&^L&"T_P``G=
MZ0YGV$;3Z0`!3/$`#``CS>D4O*-&K$8`),WI`C1/ZDD4`Y1&Z@L#W>D01<WI
M#+P<0`2;(D8&Z@L$#_(L.]OI`*L#GAKK``I&ZMAG2^L!"U!&0NH$"@.73^K8
M9%9&$.L#"D_J2!,"DTOQ``L:ZP8*W>D"9T3J211+\0`+)D,T1@&>&NL$"@&<
M2_$`"\WI$*NQ!P">HPA51D'JE@&P!T#J`00`)LWI`%9!Z@,%=*NB1@`DJT;3
MZ0`!`"/-Z0(T`9S=Z0QGS>D$JV0!`Y3=Z11%1NH*`P_RE"S<Z0"\'$`.FQOK
M``M/ZHAP(D8&Z@H$`YY,ZP$,&^L#"P";0NH$"D_JB7$W1@">3^K39$_J0Q,"
MDT'JF`$!FT?JUF<#ETSQ``S=Z0)G&^L*"T3J0Q1/ZID#1NH$!D'J`P5`Z@$$
M3/$`#':K&^L&"T_P``G=Z01GV$;3Z0`!3/$`#``CS>D4O*-&K$8`),WI`C1/
MZDD4`Y1&Z@L#W>D01<WI#KP<0`R;(D8&Z@L$#_+D&]OI`*L#GAKK``I&ZMAG
M2^L!"U!&0NH$"@.73^K89%9&$.L#"D_J2!,"DTOQ``L:ZP8*W>D"9T3J211+
M\0`+)D,T1@&>&NL$"@&<2_$`"\WI$*NQ!P">HPA51D'JE@&P!T#J`00`)LWI
M`%9!Z@,%>*NB1@`DJT;3Z0`!`"/-Z0(T`9S=Z0YGS>D,JV0!`Y3=Z11%1NH*
M`P_R2!S<Z0"\'$`$FQOK``M/ZHAP(D8&Z@H$`YY,ZP$,&^L#"P";0NH$"D_J
MB7$W1@">3^K39$_J0Q,"DT'JF`$!FT?JUF<#ETSQ``S=Z0)G&^L*"T3J0Q1/
MZID#1NH$!D'J`P5`Z@$$3/$`#'JK&^L&"T_P``G=Z0QGV$;3Z0`!3/$`#``C
MS>D4O*-&K$8`),WI`C1/ZDD4`Y1&Z@L#W>D01<WI!+P<0`Z;(D8&Z@L$#_*8
M"]OI`*L#GAKK``I&ZMAG2^L!"U!&0NH$"@.73^K89%9&$.L#"D_J2!,"DTOQ
M``L:ZP8*W>D"9T3J211+\0`+)D,T1@&>&NL$"@&<2_$`"\WI$*NQ!P">HPA5
M1D'JE@&P!T#J`00`)LWI`%9!Z@,%?*NB1@`DJT;3Z0`!`"/-Z0(T`9S=Z01G
MS>D.JV0!".``OZ'KV6X`````W+P;CP`````#E-WI%$5&Z@H##_9L;-SI`+P<
M0`R;&^L`"T_JB'`B1@;J"@0#GDSK`0P;ZP,+`)M"Z@0*3^J)<3=&`)Y/ZM-D
M3^I#$P*30>J8`0&;1^K69P.73/$`#-WI`F<;ZPH+1.I#%$_JF0-&Z@0&0>H#
M!4#J`01,\0`,?JL;ZP8+3_``"=WI#F?81M/I``%,\0`,`"/-Z12\HT:L1@`D
MS>D"-$_J210#E$;J"P/=Z1!%S>D,O!Q`!)LB1@;J"P0/]KQ;V^D`JP.>&NL`
M"D;JV&=+ZP$+4$9"Z@0*`Y=/ZMAD5D80ZP,*3^I($P*32_$`"QKK!@K=Z0)G
M1.I)%$OQ``LF0S1&`9X:ZP0*`9Q+\0`+S>D0J[$'`)ZC"%5&0>J6`;`'0.H!
M!``FS>D`5D'J`P6`JZ)&`"2K1M/I``$`(\WI`C0!G-WI#&?-Z02K9`$#E-WI
M%$5&Z@H##_8@7-SI`+P<0`Z;&^L`"T_JB'`B1@;J"@0#GDSK`0P;ZP,+`)M"
MZ@0*3^J)<3=&`)Y/ZM-D3^I#$P*30>J8`0&;1^K69P.73/$`#-WI`F<;ZPH+
M1.I#%$_JF0-&Z@0&0>H#!4#J`01,\0`,&^L&"T_P``G=Z01G3/$`#-A&S>D4
MO``CHT:L1@`DS>D"-$_J210#E$;J"P/=Z1!%@JG-Z0Z\'$#1Z0`!#)LB1@;J
M"P0/]G!+V^D`JP.>&NL`"D;JV&=+ZP$+4$9"Z@0*`Y=/ZMAD5D80ZP,*3^I(
M$P*32_$`"QKK!@K=Z0)G1.I)%$OQ``LF0S1&`9X:ZP0*`9Q+\0`+S>D0J[$'
M`)ZC"%5&0>J6`;`'0.H!!``FS>D`5D'J`P6$J:)&`",`)-'I``&K1LWI`C0!
MG-WI#F?-Z0RK9`$#E-WI%$5&Z@H##_;8/-SI`+P<0`2;&^L`"T_JB'`B1@;J
M"@0#GDSK`0P;ZP,+`)M"Z@0*3^J)<3=&`)Y/ZM-D3^I#$P*30>J8`0&;1^K6
M9P.73/$`#-WI`F<;ZPH+1.I#%$_JF0-&Z@0&0>H#!4#J`01,\0`,&^L&"T_P
M``G=Z0QG3/$`#-A&S>D4O``CHT:L1@`DS>D"-$_J210#E$;J"P/=Z1!%AJG-
MZ02\'$#1Z0`!#ILB1@;J"P0/]B@[V^D`JP.>&NL`"D;JV&=+ZP$+4$9"Z@0*
M`Y=/ZMAD5D80ZP,*3^I($P*32_$`"QKK!@K=Z0)G1.I)%$OQ``LF0S1&`9X:
MZP0*`9Q+\0`+S>D0J[$'`)ZC"%5&0>J6`;`'0.H!!``FS>D`5D'J`P6(J:)&
M`",`)-'I``&K1LWI`C0!G-WI!&?-Z0ZK9`$#E-WI%$5&Z@H##_:,+-SI`+P<
M0`R;&^L`"T_JB'`B1@;J"@0#GDSK`0P;ZP,+`)M"Z@0*3^J)<3=&`)Y/ZM-D
M3^I#$P*30>J8`0&;1^K69P.73/$`#-WI`F<;ZPH+1.I#%$_JF0-&Z@0&0>H#
M!4#J`01,\0`,&^L&"T_P``G=Z0YG3/$`#-A&S>D4O``CHT:L1@`DS>D"-$_J
M210#E$;J"P/=Z1!%BJG-Z0R\'$#1Z0`!!)LB1@;J"P0/]MP;V^D`JP.>&NL`
M"D;JV&=+ZP$+4$9"Z@0*`Y=/ZMAD5D80ZP,*3^I($P*32_$`"QKK!@K=Z0)G
M1.I)%$OQ``LF0S1&`9X:ZP0*`9Q+\0`+S>D0J[$'`)ZC"%5&0>J6`;`'0.H!
M!``FS>D`5D'J`P6,J:)&`",`)-'I``&K1LWI`C0!G-WI#&?-Z02K9`$#E-WI
M%$5&Z@H##_9$'-SI`+P<0`Z;&^L`"T_JB'`B1@;J"@0#GDSK`0P;ZP,+`)M"
MZ@0*3^J)<3=&`)Y/ZM-D3^I#$P*30>J8`0&;1^K69P.73/$`#-WI`F<;ZPH+
M1.I#%$_JF0-&Z@0&0>H#!4#J`01,\0`,&^L&"T_P``G=Z01G3/$`#-A&S>D4
MO``CHT:L1@`DS>D"-$_J210#E$;J"P/=Z1!%CJG-Z0Z\'$#1Z0`!#)LB1@;J
M"P0/]I0+V^D`JP.>&NL`"D;JV&=+ZP$+4$9"Z@0*`Y=/ZMAD5D80ZP,*3^I(
M$P*32_$`"QKK!@K=Z0)G1.I)%$OQ``LF0S1&`9X:ZP0*`9Q+\0`+S>D0J[$'
M`)ZC"%5&0>J6`;`'0.H!!``FS>D`5D'J`P60J:)&`",`)-'I``&K1LWI`C0!
MG-WI#F?-Z0RK9`$#E-WI%$5&Z@H##_+X?-SI`+P<0`2;&^L`"T_JB'`B1@;J
M"@0#GDSK`0P;ZP,+`)M"Z@0*3^J)<3=&`)Y/ZM-D3^I#$P*30>J8`0&;1^K6
M9P.73/$`#-WI`F<;ZPH+1.I#%$_JF0-&Z@0&0>H#!4#J`01,\0`,3_``"1OK
M!@M/1MWI#(E,\0`,7D;-Z12\`".C1JQ&`"3-Z0(T?`$#E-WI$$5(Z@L#DJG-
MZ01G'$#-Z1"\T>D``0`E(D8(Z@L$#_)$>=GI`(G=Z02\&.L`"`Z;2>L!"0.>
M7T9)1D+J!`D8ZP,"1NK;9D'Q``-91@.620$!GOP.`I%$ZDP4W>D">!+K"0)/
MZH9Q`)Y'Z@0'`9Q#\0`#$NL'"T/Q``Q!ZI8!L`>C",WI&+Q>1D#J`0I!Z@,+
ME*DO1M!&V4;1Z0`TW>D0`<WI#HG-Z0(T`",`),WI`#1`Z@H$W>D4JVL!`9,!
MF0KJ!`K=Z0(C!$9`1@_RF&G9Z0")0>K680&1$NL(`@3J``1#ZPD#1.H*!)!&
M"D8,F1CK`0A/ZD81`)%#\0`)W>D``1CK!`K=Z01%3_```4#J`@!)\0`+`D:K
M!P`@S>D``0&3&NL""`&:3^J4`$#JA7!/ZI4!0NJ4`T_JA'0!DT_P``4`E$_P
M``3-Z0)%2_$`"=WI`$5"1LWI#(E/\``)2T8$0PU#W>D.B:)&60&K1HCJ!`C=
MZ1A%`Y&6J83J"`3-Z02KT>D`O`_RZ%'1Z0`!H$80G!OK``M/ZM)@3.L!#!OK
M!`0#F4SQ``6B1E0!0>K280*4`Y$:ZP@$W>D"B4#J0Q!%\0`%N0A(Z@`(3_``
M"13K"`I/ZH9T1?$`"[T'1>J6!<WI$*M%Z@$,1.H%"]WI!$701LWI`KQ/ZDD1
MA.H+!`_R<%O;Z0"K0>K880&1)D;>Z0!%3^K88)D(%.L*!$#J21!%ZPL%S>D4
M10Z<W>D,JZ9&W>D418KJ!@H4ZPX$#?4@?E9&1?$`!:)&3^I(%`"4&NL&!-WI
M`&=%\0`%!D,4ZP8*3^J"=$7Q``N=!\WI#JN:JT_P``M%ZI(%7T961M/I`"-/
M\``*3_``"\WI`*M%Z@$+>0$!D43J!0H/\M1!T>D``=WI`D6`&,WI#*M9083J
M"@0!FXQ&W>D0$D/JUF,!DV%`\@Y"ZD<23^J9`PQ&!)E`&$SQ``$`&8M&3^I&
M$0"12_$``=WI`$440Q#K!`M/ZHAP0?$`#$_JB7%!ZI@!3_``"4_P``C-Z0")
M0>H#"4#J`0A<1F5&S>D010`E049*1FL!W>D,B0&3G*O-Z002B.H!"-/I``$/
M\CA#T^D`(X`864$!FXM&W>D.$D/JU&/B#H'J"`$!DT+J11*["(A&`IE`&$OQ
M``$0ZP@`BT9/ZD01`)%+\0`!W>D`B4_P``E(Z@(($.L("D_JAG!!\0`+N0=!
MZI8!T$;-Z0ZK0.H!"D'J`PL`)E)&3^I)$5M&W>D$J\WI`B.>JXKJ`@H`)\WI
M`&<!D59&ZZ+2Z0`2T^D`JP&;&NL!"DOK`@O=Z1`20^K88P&3<4!/ZMAB0NI)
M$JL(#D8,F1KK`0!+\0`!@!F+1D_J2!$`D4OQ``'=Z0!G%D,0ZP8*3^J$<$'Q
M``NI!T'JE`'-Z1"K`"1/\``+`"7-Z0!%0.H!!%]&0>H#!7L!HT8!D]WI`C2L
M1M[I``%61LWI#+R#Z@L##_(</-SI`+P-]2)^'$8!FQ#K"P!!ZPP!0^K:8P&3
M3^J9`XQ&W>D.$O(.84!"ZD<2#$8$F4`83/$``0`9BT9/ZD81`)%+\0`!W>D`
M111#$.L$"T_JB'!!\0`,3^J)<4'JF`%<1D'J`PE`Z@$(#_*P*]OI`*ME1D%&
M2D;=Z0R)S>D$$HCJ`0C>Z0`!S>D.10`E$.L*`$_J11-!ZPL!0^K48P&3NPB+
M1MWI$!+B#@WU)GZ!Z@@!0NI%$HA&`IE`&$OQ``$0ZP@`BT9/ZD01`)%+\0`!
MW>D`B4_P``E(Z@(($.L("D_JAG!!\0`+N0=!ZI8!T$;-Z1"K0.H!"D'J`PL`
M)E)&3^I)$5M&W>D$J\WI`B.DJXKJ`@H`)\WI`&<!D59&?Z+2Z0`2T^D`JP&;
M&NL!"DOK`@O=Z0X20^K88P&3<4!/ZMAB0NI)$JL(#D8,F1KK`0!+\0`!@!F+
M1D_J2!$`D4OQ``'=Z0!G%D,0ZP8*3^J$<$'Q``NI!T'JE`'-Z0ZK`"1/\``+
M`"7-Z0!%0.H!!%]&0>H#!7L!HT8!D]WI`C2L1M[I``%61H/J"P/-Z0R\#?4H
M?AQ&6:/3Z0`C@!A900&;C$;=Z1`20^K:8P&384#R#D+J1Q)/ZID##$8$F4`8
M3/$``0`9BT9/ZD81`)%+\0`!W>D`111#$.L$"T_JB'!!\0`,3^J)<5Q&0>J8
M`65&S>D010`E#_($&]OI`*M/\``(3_``"<WI`(E`Z@$(0>H#"6D!`9%"1M[I
M``%+1MWI#(D-]2Q^$.L*`,WI!"-!ZPL!`9N(Z@((BT9#ZM1C`9.["-WI#A+B
M#D+J11*!Z@@!B$8"F4`82_$``1#K"`"+1D_J1!$`D4OQ``'=Z0")3_``"4CJ
M`@@0ZP@*3^J&<$'Q``NY!T'JE@'01LWI#JM!Z@,+0.H!"D_J21-:1@`F44;=
MZ02K`"?-Z0!GBNH!"@&3JJO-Z0(25D;3Z0"K$*/3Z0`C&NL""MWI$!)+ZP,+
M`9MQ0$_JV&)#ZMAC`9,.1@R90NI)$JL(&NL!`$OQ``&`&8M&".``O]R\&X\`
M````UL%BR@````!/ZD@1`)%+\0`!W>D`9Q9#$.L&"D_JA'!!\0`+J0=!ZI0!
MS>D0JP`D3_``"P`ES>D`14#J`01?1D'J`P5[`:-&`9/=Z0(TK$;>Z0`!5D:#
MZ@L#S>D,O`WU+GX<1@_R(%/3Z0`C@!A900&;C$;=Z0X20^K:8P&384#R#D+J
M1Q)/ZID##$8$F4`83/$``0`9BT9/ZD81`)%+\0`!W>D`111#$.L$"T_JB'!!
M\0`,3^J)<4'JF`%/\``)3_``",WI`(E`Z@$(0>H#"5Q&94;-Z0Y%`"5"1@_R
MJ$O;Z0"K2T9I`=WI#(D!D<WI!".(Z@((WND``0WU,GX!FQ#K"@!!ZPL!0^K4
M8P&3NPB+1MWI$!+B#H'J"`%"ZD42B$8"F4`82_$``1#K"`"+1D_J1!$`D4OQ
M``'=Z0")3_``"4CJ`@@0ZP@*3^J&<$'Q``NY!T'JE@'01LWI$*M!Z@,+0.H!
M"D_J21-:1@`F44;=Z02K`"?-Z0!GBNH!"@&3L*O-Z0(25D;3Z0"K_J/3Z0`C
M&NL""MWI#A)+ZP,+`9MQ0$_JV&)#ZMAC`9,.1@R90NI)$JL(&NL!`$OQ``&`
M&8M&3^I($0"12_$``=WI`&<60Q#K!@I/ZH1P0?$`"ZD'0>J4`<WI#JL`)$_P
M``L`)<WI`$5`Z@$$7T9!Z@,%>P&C1@&3W>D"-*Q&WND``59&@^H+`\WI#+P-
M]31^'$;:H]/I`".`&%E!`9N,1MWI$!)#ZMIC`9-A0/(.0NI'$D_JF0,,1@29
M0!A,\0`!`!F+1D_J1A$`D4OQ``'=Z0!%%$,0ZP0+3^J(<$'Q``Q/ZHEQ7$9!
MZI@!94;-Z1!%`"4/\@@[V^D`JT_P``A/\``)S>D`B4#J`0A!Z@,):0$!D4)&
MWND``4M&W>D,B0WU.'X0ZPH`S>D$(T'K"P&(Z@((`9N+1MWI#A)#ZM1C`9.!
MZ@@!X@Y"ZD42NPB(1@*90!A+\0`!$.L(`(M&3^I$$0"12_$``=WI`(E/\``)
M2.H""!#K"`I/ZH9P0?$`"[D'0>J6`=!&S>D.JT'J`PM`Z@$*3^I)$UI&`"91
M1MWI!*L`)\WI`&>*Z@$*`9.VJ\WI`A)61M/I`*N0H]/I`",:ZP(*W>D0$DOK
M`PL!FW%`3^K88D/JV&,!DPY&#)E"ZDD2JP@:ZP$`2_$``8`9BT9/ZD@1`)%+
M\0`!W>D`9Q9#$.L&"D_JA'!!\0`+J0?-Z1"K3_``"U]&0>J4`4'J`PP`)'L!
M`"7-Z0!%0.H!"P&35D;=Z0(TWND`$@WU.G[-Z0R\@^H+`P_RM!O;Z0"K'$8!
MFQ'K"@%"ZPL"0^K68XI&`9.31MWI#A+R#D_JF0-A0$+J1Q(,1@29&NL!`$OQ
M``$`&8M&3^I&$0"12_$``=WI`$4`)11#$.L$"T_JB'!!\0`,3^J)<4'JF`%<
M1D'J`PE`Z@$(S>D`14%&2D;=Z0R)3^J7"=[I`#0-]3Q^W>D018CJ`0C-Z002
MA.H(!$BBTND`$LWI#KQ/ZH=[H$8`G%L82^J6"TOJ"07=^/S"X`X"G*E&&AD!
MG!+K"`(`(T#J1!``G$_J1!I`Z@H`3^J&>DKJ"P3=Z02K$AC>Z0!GH$:+Z@4+
M7`&*Z@@*1.K2;MWI#D7-Z1")T$;91@_RM`O;Z0"KA.H(!(7J"07-Z0Y%&NL&
M"@R<<$;-^`S@`",:ZP0&5`$"E$_P``D.G#89W>D"101#($8`G#88W>D&`0`A
M3^J4"MWI`$6`&4_JA'@<G$KJA7K=Z0I62.H*",3I``'=Z18!'9F`&-'X`.`"
M1A"9;1@N1MWI$D4$F0`E9!C=Z0@!`"$0ZP@`L$8<GO1%QND"(\;I!HG&Z0A%
MQND$`0/1#?5!?;WH\(_\]Y;L`+^O\P"`UL%BR@`````MZ?A#'4M[1!"S'4J;
M6-/X`)"Y\0`/+M`%>``M&+\]+12_`24`)171V?@`0'RQ@$8/1DY&*D9!1B!&
M_/=^[1"Y8UT]*P_05O@$3P`L\M$@1KWH^(,%1A7X`3\`*QB_/2OYT2T:X.>F
MZPD&:!P@1+80/F"]Z/B#2$:]Z/B#^F,!`%`!``#PM8.P%4\%1A5+;$9_1/Y8
M,V@!DR%&*$;_][#_L+$12P"8^U@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`
M*OK1(48H1O_WFO\`*.C1`9HS:)I"`=$#L/"]_/<>['!C`0`8`0``4`$``"WI
M\$\,1M_X7)&%L%9+!D;Y1`IX6?@#4#TJ"+\!-"MH($8#D_SW?NP"J0=&,$;_
M]W'_@$8`*%/0_/=T[(="1ME*2P*:6?@#D$_J@@@P>``H&+\]*!2_`2``(`?0
M,$80^`$_`"L8OSTK^=&`&P(WV?@`H#A$_/<R[$KX"```*&O0V?@`('$<`I@S
M>%+X(``]*QB_`"L#<`G00AP1^`$[$$8`*QB_/2L"^`$[]M$"1CTC`W`4^`$[
M`O@!/P`K^=$`(`.:*VB:0DK1!;"]Z/"/"/'_,!3X`3L`^`$_`"OYT>[G(DM9
M^`.0V?@`L-OX`#"#LUM&`.!01E/X!"\`\0$*`"KXT0,P@``:2GI$$VB#L0%&
M6$;\]Z+KR?@``.BQ3^J*"`KQ`0,`(D#X(R#-^`B@C><!(Q-@_/?2ZP&0:+%/
MZHH(649"1OSW1.L!FQA&R?@`,.;GFD8((-;G3_#_,+#G_/=HZP"_!&,!`!@!
M``!0`0``P&,!`#)+,TI[1"WI\$.?L)]8.V@=DQ"Q`W@%1C.Y'9H[:)I"4M$?
ML+WH\(/\]Y+K!D8`*//0W_B@@/A$,$;\]S;L@+/#?"XK--``\1,$*$;\][#K
M@48@1OSWK.M(1`(P_/>$ZT-&3_#_,@$A`90`E8%&_/>^ZTE&`JH#(/SW*.P!
M,$A&!=`&FP/T<$.S]8!/&=#\]R3K2$;\]^CJ,$;\]P;L`"C.T3!&_/<P["A&
M_/?PZK3G`WT`*\#0+BO%T4-]`"N[T,'G__>=_^3G_/?XZIQA`0`8`0``BA,`
M`#BU!4852Q9*>T2<6"!H_/<6["E&`/6D<@,@_/<$[`BQ`"`XO2!H_/<*[-#X
M6#$#]'!#L_6`3PG0(&C\]P#LT/A8,0/T<$.S]2!/Z=$H1@(A_/>LZ[#Z@/!`
M"3B]P&`!`"`!```MZ?!!K?6`782P(DP#JPWU@%4!DWQ$($L'1B!(##6(1D#V
M_W+F6'A$`9DS:"M@_/?.Z@`H(MT!FT4>6UWCL05&*D8O(0&8_/=ZZ[BQ%$OC
M6!AH_/?"ZRM&`9HY1OSWC.L-]8!3##,::#-HFD(0T0WU@%T$L+WH\($`+>'1
M"$OC6!AH_/>JZT)&.4;\]YKJY^?\]W;J4&`!`!@!``!F$@``(`$``!"U"$P(
M2WQ$XU@8:/SWDNL&2@=+!TFB6'M$>42]Z!!`_/<(N[I?`0`@`0``'`$``)@1
M``#>$0``#4L.2GM$$+6"L)Q8(&C\]W;K__?9_R!H_/=PZP`A"$L!D0A*>T0(
M27I$`)-Y1/SW$NL"L!"]`+^$7P$`(`$``(P4``#=#0``L!$``")+(TI[1/"U
MK?4`79U8A[`-]0!2`ZX4,AY,*VA\1!-@_/>(ZAQ+0?(!`@$A>T2-Z!$`,$;\
M]ZCJ`"@AVPWU@%<P1A`W3_2`4CE&_/<LZ@0>%MM@'/SW5NH&1IBQ.48B1OSW
MW.DP1@`C,U4-]0!3%#,::"MHFD(&T0WU`%T'L/"]`"#RY_'G_/?HZ0"_.%\!
M`!@!``"8$0``?!$``/_WL+\MZ?!/K?6!7=_X5(&#L%5+!$;X1`WU@5)32`0R
M6/@#,`WQ*`D-1GA$J?$(`0>3&V@38/_W,_TO(09&($;\]T+JD+%*2"%&>$3_
M]Y[]($8-]8%3!#,::`>;&VB:0GW1#?6!70.PO>CPCR!&_/<@ZD!)>42#1BA&
M_/>*Z@=&`"C@T-_X\*`\2_I$>T0%DSM+>T0&DSMX`"L(OU=&+K$Y1C!&_/<\
MZ0`H0=`X1OSW`.I"'KL8NEPO*@;1`"$9<`$X$_@!+2\J^=`+\0$#&$2P]8!?
MM]H&FZGQ!`5/](!2`2$`ERA&`9,"E`6;_/?^Z21+6/@#<#AH_/>,ZBE&`/6D
M<@,@_/=BZDBY.&C\]X+JT/A8,0/T<$.S]0!/$-`:20`@>43\]S3J!T8`+[/1
MBN<627E$_/<LZ@=&`"^KT8+G`2$H1OSW'NH`*.C1$$@I1GA$__<;_2A&_/?6
MZ7GG_/<NZ0"_BEX!`!@!``#V$```XA```,@0``"2$```M!```+80```@`0``
M&A````H0``#<#P```W@[L4(<+RL(OQ!&$O@!.P`K^-%P1P"_.+60LP5X!$9]
ML_SW?.D!."(8E$(,TB-<+RLOT5,>`N`1>"\I*M&C0AI&`_'_,_?1E$(OT`$Z
M`^`1>"\I!-$:1I1"`O'_,_?3$AN3'+/U@%\2V!1((48!,D_T@%-X1`0=($;\
M]]#H($8XO0(@_/<FZ1"Q+B("@#B]`"`XO5,>`N`1>"\IUM"<0AI&`_'_,_?3
ME$+/T2\MZ-`#2+WH.$!X1/SW6KE,7@$`_@X``"WI\$&,L$I,`JU*3WQ$2DX,
M-']$W_@D@0_,^$2_60&N#\4/S-?X`.`/Q21H1$C-^"S@>$0L@/_W2?Q"2'A$
M__=%_$%(>$3_]T'\0$AX1/_W/?P_2'A$__<Y_#Y(>$3_]S7\/4AX1/_W,?P\
M2'A$__<M_$!&__<J_#E(>$3_]R;\.$AX1/_W(OPW2'A$__<>_#9(>$3_]QK\
M-4@Q1GA$__?3^QBQ`49`1O_W1/PQ2#%&>$3_]\G[(+$!1B](>$3_]SG\+D@Q
M1GA$__>^^XBQ`48K2'A$__<N_"I)*TAY1'A$__<H_`N:.VB:0A[1#+"]Z/"!
M)D@Q1GA$__>F^RBQ`48C2'A$__<6_.;G(DD*(@WQ&0!Y1/SW-.D`*-W1'D@-
M\2,!>$3_]P;\UN?\]QSH`+\L#@``-EP!`!@!```J#P``P@X``,0.``#$#@``
MR`X``,@.``#0#@``9`X``,P.``#6#@``4@X``-(.``#6#@``V`X``-@.``#@
M#@``X@X``/8-``#\#@``/@X``,(.```V#@``N@X``!8.```221-*>4032Q"U
M>T2,6(*P&&@C:`&30QP%T`&:(VB:0A+1`K`0O0Q(:49X1/_W/OLPL0!X,"@8
MOP`H%+\!(``@!DM[1!A@Z.?[][[OJ%H!`!@!``#^6P$`<@T``,9;`0`(M?OW
M?._[]V[O`+$`:`B]+>GP3P9&+TR1L-_XO.`(K7Q$W_BXP`0T_D0O1@_,7O@,
M@`_'E.@'`-CX`#`(G(?H!P`/D_RQW_B8H`>OW_B4D/I$^40&X#%&^_<R[]BQ
M5?@$3X2Q.48@1O_W\/J#1A"Q`G@`*N_1($8Q1O_W7?M5^`1/`"SNT0^:V/@`
M,)I"']$1L+WH\(\P1OOWX.\%D%A&^_?<[P6;&$0",/OWM._-^`BP4T;-^`20
M3_#_,@"6`2$%D/OWZN\%F2!&__<U^\;G^_=*[XA;`0`D6@$`&`$``)P,``"6
M#```+>GP3ZWU`4W?^%A'D[!2J]_X5(=\1`N3!/$@`AY&W_A,-_A$#)"F\?@'
M!\H$\2P.6/@#,*;QX`M$-*;Q[`G:1OP^'48-DX?H!P"^Z`\`U?@`P*KH#P`-
M]0%#GN@#`$0SP_@`P(KH`P"4Z`<`B>@'`#%&W_C\!GA$__=T^B"Q`W@$1@`K
M0/"&@?_W1O\%1@`H4]`H1OOW;N]```$P^_=&[RMX@4:#L=_XS*8$1OI$`),@
M1E-&3_#_,@$A`C3[]WCO%?@!/P`K\M$+FU/XX`P8N13@6_@$#XBQ,4;_]T/Z
M!$8`*/;0`W@`*_/0__?7^P`H[]`@1OOW:N^"1G"["YM3^/A,1+,C>`$E,[DD
MX%?X)4`,LR-X`37SL2!&__>_^P`H]-`@1OOW4N\`*._0@D84X/OW3.\`*$#P
M*X%9^`0+`"@`\"Z!,4;_]PWZ`"CUT`-X`"ORT.SG3_``"E!&W_@85OOW".]]
M1`1&2$;[]P3O($0`\@1$($;[]]KNW_@`-D_P_S(!(7M$`9/?^/0US?@,D'M$
MS?@`H`*5@T;[]PKO6$9/].!Q^_<@[P$P+-#?^-0U6/@#4"AH^_>0[UE&`/6D
M<@,@^_=^[P`H--#?^+P%`2$,F]_XN"58^```&VAZ1,WX`+``:/OW'N\`(`WU
M`4-$,QIH#9L;:)I"0/";@@WU`4T3L+WH\(_[]\[N`&@1*,W0W_AT10$A#)O?
M^'0E6/@$0!MH>D0!D,WX`+`@:/OW^NX`(-KG*&C[]U#OT/A8,0/T<$.S]8!/
MP-$H:/OW1N_0^&!Q^_?@[8="M]$H:/OW/._0^%@QP_,(`[/UX'^MT2!&^_=<
M[C%&!$;?^!@%>$3_]W'Y`"@`\)&`#)L=:/OWGNX!1BA&__<8_`5&`"@`\(6`
M*$;[]VCN`R@&1A#=W_CH%`0X*$1Y1/OWENU`N00N`/#?@2Y$%O@%/"\K`/#9
M@?_W\_TPN0%&*$;[]R+N#I``*&;1W_BX%``FW_BT!'E$W_BT='A$W_BPE/_W
MJOE_1/OW+N[?^*@TW_BH%$_P_S)[1`&3W_B@-'E$W_B<A+I&`Y%[1,WX`+`!
M(?E$^$1?1@*0($;[]S[N%.#[]S3N`V@1*Q?1^_<,[@$VS?@0@"I&`Y9+1LWX
M!*`!(0"7`I`@1OOW*.Y/].!Q($;[]S[N0QP%1N+0NT981OOW6NW?^$`$(49X
M1/_W9?D@1O_WSOT@1BSG!49^YO_WR/T@1OOW&.XDY]_X'%0-('U$>.8,FQUH
M=^<+GV_P$0(")0"5.Q\,DQY&3_#_,_OWFNTQ1@8B#IC[]QSM%_@$/!NY<WA#
M*P#P=($`)0`B`",`E0Z8^_>([0N>TJ'1Z0`!IO'("M*CT^D`(\KX>%#*Z0(!
MIO&0`0^1SZ'1Z0`!RND$(\ZCT^D`(\KI!@'.H='I``'*Z0@C`"(`(Q"4RND*
M(\KI#"-&Z3(!S?A$L$_T`$(,F0Z8^_?>[`0>?-WG%]KI"B,F1OD`0>I4<0>1
MX0`&D=WI!HE/\``)&.L"")E%"+^01=KI#","T@$R0_$``W$/VOAX`$'JQP$(
MD7D/"9'=Z0A6RND*B:T87D$J1C-&RND,(P`H3-#`\4`(#YN@10R9&$2HOZ!&
M0D;[]\+LVOAX,$-$ROAX,$`KN-$,FU!&I.L(!)A$^_>'_S\L*-U`/`N="/%`
M#$_JE!L+\0()".N)&:SQ0`:E\9`.,&@0-E;X#!QW1E;X""P.\1`.5O@$/&9%
M#\?QT5!&^_=F_P;Q0`S,1>;1"_$!`Z3KBQ0(ZX,8049((R)&#YC[]\SLROAX
M0'WGW?@P@,CG"YL.F*/QD`<0G-WX1+#[]ZSMVO@H4(`AVO@P8,7SQ0)3'#@K
MN50`\YJ`^!C#\3@"`"'[]SKM4$8J#C,.BOAT((KX<V"*^'=0BOAP,#,,-@J*
M^'$PBOAR8"L,+0J*^'4PBOAV4/OW'/\+F-KX"&"@\40"VO@04%#XR.R@\3`'
MH/$Q"-_X])'5<D_J'D%/ZAYC47#Y1-KX(!``^$0\VO@8`(+X`^!/ZAXNT72"
M^`+@3^H6;M!S@O@$X$_J%DZ"^`7@UG$V"I9Q+@X6<BX,+0I6<I5R%D8%#A5S
M!0P`"E5S/4:0<P@.$'0(#`D*4'21=`'@%O@!/P"3*$9+1D_P_S(!(0(U^_>P
M[+!%\M%<2$_P_S);2P$A>$0"EP.0>T3-^`"P($8!DP`CA_@H,%9+>T3[]YKL
M>>8,FUYH`"X_]"*N,$;[]W+L`RA_]ARN3TD$.#!$>43[]Z+K`"@(OS5&$>;#
M\4`"^!@`(?OWH.Q01OOWF/XX1C@B`"'[]YCL7.<,FYMX02M_](>N#)O;>$,K
M?_2"K@R;&WE(*W_T?:X,FUMY12M_]'BN`)5/\/\S#IUO\#D"*$;[]_[K#)XH
M1BDB,TTQ1OOW?.LR2WU$3_#_,GM$`9,P2P$A`I8@1LWX`+![1`.5^_=`["#F
M^_>FZP"_K_,`@(FKS>\`````_MRZF`````!V5#(0`````/#ATL,``````2-%
M9P````"L6@$`0ED!`!@!``!N"P``5`P``+`+``"("@``>`L``"`!```H`0``
MP`L``/H*``!D#```I`H```@*``!B"0``$`D``&`*``#^"```=@L``%@*``!B
M"P``9`@``%()```B!P``+`@``*8%``#P!@``Q`8``'H'``#T!```0`8``)=*
MF$DMZ?!/>D2'L)9+!*P"E%!8`6@#D`61UE@P:/OW:NP!(R%&@/AE,)!(>$3^
M]Z?^&+$#>#$K`/#>@/_W?/HP:/OW6.R*20LC`2)Y1/OWB.L`*$O0ATL":7M$
M4_CT/-+X&(`!*T+=W_@,HD_T@&G?^`BRP/(@"?I$`"7[1`$D(^`!:%KX\`R+
M:%#X)'`)Z@,#L_6`;PB_"6D*T#!H`9+[]RCL`9H"(Q%H`"+[]RCK`48X1OOW
MI.H`*$#PE(!;^/0\`30!-:-"#MTP:/OW$NPJ1@`C04;[]]+K`D8`*-#19TM[
M1%/X]#Q:'JI":M`P:/OW`.QC20,C`2)Y1/OW,.L$1G"Q,&C[]_;K(VE>2AEH
M>D3[]^3J(VD;:)MH6P(`\8F`,&C[]^;K6$D#(P$B>43[]Q;K!$9XL55(`IEX
M1/[W'_X%1C!H`"UHT/OWU.LC:2I&&6C[]\+J,&C[]\SK34U]1`1&,&C[]\;K
M2TD!(GE$^_<@ZTE*>D0!1B!&^_>NZC!H^_>XZP`B`ID#1D1(@_AE('A$_O?T
M_01&1?CL#("S3_3@<2!&^_<NZT,<$2@8OP$K2=@#FP6:&VB:0D+1!["]Z/"/
M`2N2W39-`21]1#!H`33[]Y#K04;[]SSJ5?CT/*-"]-R#YS!+>T13^/0\6AZJ
M0G_T?*_EYT-X`"L_]""O'.=5^/`,__<)^P1&1?CL#``HQ=$E2'A$^_?>ZOOW
M:NLC2R)I>T13^/`\$&@9:/[W=?^1YS!H^_=>ZR-I&6C[]_3J;N?[]RKJ&DD#
M1AI((D9Y1'A$4?CP'`EH^_>^Z@"_>%$!`!@!```@`0``*`0``,`%``#28P$`
MM&,!`+!C`0!*8P$`&@4```@%``#R!```T`(``,QB`0"V!```Q@0``&X"``!@
M8@$`1&(!`"X$```(8@$`W&$!`!8$```XM05&__?D^`-X!$8[L4(<+RL(OQ1&
M$O@!.P`K^-'_]_OY`"T8OP`H"-`K>#.Q!DD@1GE$^_>`Z81"`-`XO2A&O>@X
M0/[W;KY"`@``!4L0M'M$!4P;60.Q&VA=^`1+^_?%N0"_=$X!`#`!```MZ?A#
M!T8+3HA&"TV11GY$^_=,Z7U$=ANV$`G0`"0!-%7X!#M*1D%&.$:81[1"]M&]
MZ/B#,DT!`"A-`0!P1P"_"$`MZ0B`O>@!``(`<&5R;'AS:2YC````7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("``````)7,O)7,````O<')O8R]S
M96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L
M<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``
M````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@``
M``!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$
M`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(
M10```%!!4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`
M````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,
M7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````4UE3
M5$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE
M=25S````)7,E<W1E;7`M)74M)74E<P`````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!!4D=6`````!@```!P97)L`````#````!0
M05(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`S-0```%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M+64``"TM``!54T52`````%5315).04U%`````%1%35!$25(`5$U0`"]T;7``
M````3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(`````$19
M3$1?3$E"4D%265]0051(````4TA,24)?4$%42```979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A
M<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G
M"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP
M+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP
M.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM0
M05)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B
M?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!
M4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID96QE=&4@)$5.
M5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D
M7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL
M"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM
M>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%2
M3E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA
M<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O
M9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@
M*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E
M:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B
M)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@
M)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D
M(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B
M=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S
M970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@
M*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED
M>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L
M(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R
M.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL
M;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY
M("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH
M7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T+"`D9FEL96YA
M;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U="D@>PIB:6YM
M;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["F-H;6]D
M(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]
M?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2![
M"FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT
M(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@;7D@)&]U="P@
M)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN
M="`D;W5T("1B=68["F-L;W-E("1O=70["GT*96QS92!["B1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L
M;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@
M)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)
M3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@
M:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*
M9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<
M421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U
M:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX[
M"B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92([
M"FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN
M97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT[
M"G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O
M=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C
M?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&9I
M;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG
M+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*
M?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D
M=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE
M;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA
M;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E
M('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA
M;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!
M4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE
M;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H
M0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E
M("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$
M:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P
M87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I
M('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N
M(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G
M.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@
M9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H
M4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!
M4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I
M;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD
M:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;
M)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B
M7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q
M=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@
M9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I
M(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@
M)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R
M961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I
M9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R
M="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1
M)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>
M0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T
M.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H
M(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN
M960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U
M=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF
M("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L
M<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N
M("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^
M.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R
M:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H
M:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^
M<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I
M(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@
M*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!
M0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C
M:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R
M:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O
M=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]
M("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@
M;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E
M<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I
M;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H
M;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@
M>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N
M86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR
M97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S
M=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER
M92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q
M=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U
M:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!
M4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@
M<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z
M.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]
M"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@
M/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R
M;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN
M3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*
M96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D
M<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K
M("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@
M)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG
M97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R
M<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD
M8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS
M92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@
M>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H
M*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@
M*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H
M)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!]
M(#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D
M8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B
M)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU
M;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL
M92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA
M;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE
M;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I
M;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%
M3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H
M+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92![
M"B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G
M;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_
M7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES
M=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@
M(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[
M4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@
M*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@
M/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD
M14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]
M*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H
M)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT
M(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA
M9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I
M;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PHQ.PI?7T5.1%]?"@`H=O]_`0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````%&0``Q1@````````!`````0````$```#?`0``
M`0```"X"```!````B0,```P```#\$@``#0```)!@```9````D*T!`!L````$
M````&@```)2M`0`<````!````/7^_V^T`0``!0```)`)```&````H`(```H`
M```%!0``"P```!`````5``````````,```"LK@$``@`````"```4````$0``
M`!<```#\$```$0```-0/```2````*`$``!,````(````&`````````#[__]O
M`0``"/[__V]T#P``____;P,```#P__]OE@X``/K__V\7````````````````
M`````````````````````````````````````````)RM`0````````````@3
M```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,`
M``@3```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``
M"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```(
M$P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3
M```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,`
M``@3```($P``"!,```@3```($P``"!,```@3``"-8```````````````````
M```````````````````````````$L`$``````%%@````````*18`````````
M````````````````````!+`!`/____\(9```&&0``"!D```H9```,&0``$1D
M`````````&0``"AA`````````&(```1B``#T8P``,&$``/QC````````X&,`
M`.AC````````4&0``$=#0SH@*%5B=6YT=2],:6YA<F\@-2XT+C`M-G5B=6YT
M=3$I(#4N-"XP(#(P,38P-C`Y`$$R````865A8FD``2@````%-RU!``8*!T$(
M`0D""@02!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN=&5R<``N
M;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN
M97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`
M+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB
M=71E<P``````````````````````````````````````````````````````
M"P````$````"````5`$``%0!```9```````````````!`````````!,````'
M`````@```'`!``!P`0``(```````````````!``````````A````!P````(`
M``"0`0``D`$``"0```````````````0`````````-````/;__V\"````M`$`
M`+0!``#L````!0`````````$````!````#X````+`````@```*`"``"@`@``
M\`8```8````#````!````!````!&`````P````(```"0"0``D`D```4%````
M``````````$`````````3@```/___V\"````E@X``)8.``#>````!0``````
M```"`````@```%L```#^__]O`@```'0/``!T#P``8`````8````#````!```
M``````!J````"0````(```#4#P``U`\``"@!```%``````````0````(````
M<P````D```!"````_!```/P0`````@``!0```!8````$````"````'P````!
M````!@```/P2``#\$@``#```````````````!`````````!W`````0````8`
M```($P``"!,``"`#``````````````0````$````@@````$````&````*!8`
M`"@6``!H2@`````````````(`````````(@````!````!@```)!@``"08```
M"```````````````!`````````".`````0````(```"88```F&```#1!````
M``````````0`````````E@````$``'""````S*$``,RA```(````#0``````
M```$`````````*$````!`````@```-2A``#4H0``!```````````````!```
M``````"K````#@````,```"0K0$`D*T```0```````````````0`````````
MMP````\````#````E*T!`)2M```$```````````````$`````````,,````!
M`````P```)BM`0"8K0``!```````````````!`````````#(````!@````,`
M``"<K0$`G*T``!`!```&``````````0````(````T0````$````#````K*X!
M`*RN``!4`0`````````````$````!````-8````!`````P````"P`0``L```
M7```````````````!`````````#<````"`````,```!<L`$`7+```!@0````
M``````````0`````````X0````$````P`````````%RP```S````````````
M```!`````0```.H````#``!P``````````"/L```,P```````````````0``
M```````!`````P``````````````PK```/H```````````````$`````````
